diff --git a/.travis.yml b/.travis.yml
index df6e24a7e02..b48a3667bb0 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -44,16 +44,20 @@ jobs:
#allow_failures:
#- php: nightly
include:
- - if: type = push
+ - stage: PHP 5.6-7.4
+ if: type = push
php: '5.6'
env: DB=postgresql
- - if: type = pull_request OR type = push
+ - stage: PHP 5.6-7.4
+ if: type = pull_request OR type = push
php: '7.4'
env: DB=mysql
- - if: type = push AND branch = develop
+ - stage: PHP Dev
+ if: type = push AND branch = develop
php: nightly
env: DB=mysql
- - if: type = push AND branch = 14.0
+ - stage: PHP Dev
+ if: type = push AND branch = 14.0
php: nightly
env: DB=mysql
@@ -412,10 +416,11 @@ script:
- |
echo "Enabling new modules"
# Enable modules not enabled into original dump
- cd htdocs/install
- php upgrade2.php 0.0.0 0.0.0 MAIN_MODULE_API,MAIN_MODULE_PRODUCTBATCH,MAIN_MODULE_SUPPLIERPROPOSAL,MAIN_MODULE_STRIPE > $TRAVIS_BUILD_DIR/enablemodule.log
+ set -e
+ php upgrade2.php 0.0.0 0.0.0 MAIN_MODULE_API,MAIN_MODULE_PRODUCTBATCH,MAIN_MODULE_SUPPLIERPROPOSAL,MAIN_MODULE_STRIPE,MAIN_MODULE_EXPENSEREPORT > $TRAVIS_BUILD_DIR/enablemodule.log
php upgrade2.php 0.0.0 0.0.0 MAIN_MODULE_WEBSITE,MAIN_MODULE_TICKET,MAIN_MODULE_ACCOUNTING,MAIN_MODULE_MRP >> $TRAVIS_BUILD_DIR/enablemodule.log
php upgrade2.php 0.0.0 0.0.0 MAIN_MODULE_RECEPTION,MAIN_MODULE_RECRUITMENT >> $TRAVIS_BUILD_DIR/enablemodule.log
+ php upgrade2.php 0.0.0 0.0.0 MAIN_MODULE_KNOWLEDGEMANAGEMENT,MAIN_MODULE_EVENTORGANIZATION,MAIN_MODULE_PARTNERSHIP >> $TRAVIS_BUILD_DIR/enablemodule.log
echo $?
cd -
set +e
diff --git a/ChangeLog b/ChangeLog
index 1fdb321822f..98c22d90bf7 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -64,7 +64,7 @@ NEW: VAT payment request and VAT payment are now 2 different steps in workflow o
NEW: VAT report - Optimisation & collapse by rate
NEW: When a doc file is shared, link is visible from the main page of doc.
NEW: #16378 more E-Mail Contact substitution Values for better salutation
-NEW: option to keep the "Automatically create a total payment" checkbox empty on the tax creation page
+NEW: option to keep the "Automatically create the payment" checkbox empty on the tax creation page
Accountancy
NEW: Accountancy - Add FEC import
@@ -225,6 +225,7 @@ Following changes may create regressions for some external modules, but were nec
* If your database is MySQL or MariaDB, you need at least version 5.1
* Function set_price_level() has been renamed into setPriceLevel() to follow camelcase rules
* removed deprecated subtituion key __REFCLIENT__ (replaced with __REF_CLIENT__)
+* Removed constant MAIN_COUNTRIES_IN_EEC. You can now set if country is in Europe or not from the dictionary of countries.
***** ChangeLog for 13.0.3 compared to 13.0.2 *****
@@ -284,7 +285,6 @@ FIX: test must be === and not ==
FIX: test on link type
FIX: type link extrafield case for advanced target emailing
FIX: Write right on document
->>>>>>> branch '13.0' of git@github.com:Dolibarr/dolibarr.git
***** ChangeLog for 13.0.2 compared to 13.0.1 *****
diff --git a/htdocs/accountancy/journal/purchasesjournal.php b/htdocs/accountancy/journal/purchasesjournal.php
index 9b979da37d6..71358770775 100644
--- a/htdocs/accountancy/journal/purchasesjournal.php
+++ b/htdocs/accountancy/journal/purchasesjournal.php
@@ -103,7 +103,7 @@ if (!GETPOSTISSET('date_startmonth') && (empty($date_start) || empty($date_end))
$date_end = dol_get_last_day($pastmonthyear, $pastmonth, false);
}
-$sql = "SELECT f.rowid, f.ref as ref, f.type, f.datef as df, f.libelle,f.ref_supplier, f.date_lim_reglement as dlf, f.close_code,";
+$sql = "SELECT f.rowid, f.ref as ref, f.type, f.datef as df, f.libelle,f.ref_supplier, f.date_lim_reglement as dlr, f.close_code,";
$sql .= " fd.rowid as fdid, fd.description, fd.product_type, fd.total_ht, fd.tva as total_tva, fd.total_localtax1, fd.total_localtax2, fd.tva_tx, fd.total_ttc, fd.vat_src_code,";
$sql .= " s.rowid as socid, s.nom as name, s.fournisseur, s.code_client, s.code_fournisseur, s.code_compta, s.code_compta_fournisseur,";
if (!empty($conf->global->MAIN_PRODUCT_PERENTITY_SHARED)) {
diff --git a/htdocs/adherents/list.php b/htdocs/adherents/list.php
index 7a4a7d5bc1f..d669270b565 100644
--- a/htdocs/adherents/list.php
+++ b/htdocs/adherents/list.php
@@ -363,13 +363,13 @@ if ($search_type > 0) {
$sql .= " AND t.rowid=".((int) $search_type);
}
if ($search_filter == 'withoutsubscription') {
- $sql .= " AND (datefin IS NULL OR t.subscription = 0)";
+ $sql .= " AND (datefin IS NULL OR t.subscription = '0')";
}
if ($search_filter == 'uptodate') {
- $sql .= " AND (datefin >= '".$db->idate($now)."' OR t.subscription = 0)";
+ $sql .= " AND (datefin >= '".$db->idate($now)."' OR t.subscription = '0')";
}
if ($search_filter == 'outofdate') {
- $sql .= " AND (datefin < '".$db->idate($now)."' AND t.subscription = 1)";
+ $sql .= " AND (datefin < '".$db->idate($now)."' AND t.subscription = '1')";
}
if ($search_status != '') {
// Peut valoir un nombre ou liste de nombre separes par virgules
diff --git a/htdocs/admin/emailcollector_card.php b/htdocs/admin/emailcollector_card.php
index 724c4ab6dd4..4e2c9e34bf9 100644
--- a/htdocs/admin/emailcollector_card.php
+++ b/htdocs/admin/emailcollector_card.php
@@ -482,13 +482,13 @@ if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'crea
print '';
// Filters
- print '
| '.$form->textwithpicto($langs->trans("Filters"), $langs->trans("EmailCollectorFilterDesc")).' | '; print ' | |
| '; $arrayoftypes = array( 'from'=>array('label'=>'MailFrom', 'data-placeholder'=>$langs->trans('SearchString')), @@ -518,7 +518,7 @@ if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'crea 'isnotanswer'=>array('label'=>'IsNotAnAnswer', 'data-noparam'=>1), 'isanswer'=>array('label'=>'IsAnAnswer', 'data-noparam'=>1) ); - print $form->selectarray('filtertype', $arrayoftypes, '', 1, 0, 0, '', 1, 0, 0, '', 'maxwidth500', 1, '', 2); + print $form->selectarray('filtertype', $arrayoftypes, '', 1, 0, 0, '', 1, 0, 0, '', 'maxwidth300', 1, '', 2); print "\n"; print ' |
diff --git a/htdocs/adherents/class/adherent_type.class.php b/htdocs/adherents/class/adherent_type.class.php
index 1cb9fcdb12c..ad24b9f1c05 100644
--- a/htdocs/adherents/class/adherent_type.class.php
+++ b/htdocs/adherents/class/adherent_type.class.php
@@ -656,19 +656,19 @@ class AdherentType extends CommonObject
/**
* Return clicable name (with picto eventually)
*
* @param int $withpicto 0=No picto, 1=Include picto into link, 2=Only picto
* @param int $maxlen length max label
* @param int $notooltip 1=Disable tooltip
* @return string String with URL
*/
- public function getNomUrl($withpicto = 0, $maxlen = 0, $notooltip = 0)
+ public function getNomUrl($withpicto = 0, $maxlen = 0, $notooltip = 0, $morecss = '', $save_lastsearch_value = -1)
{
global $langs;
$result = '';
- $label = '';
-
$label = img_picto('', $this->picto).' '.$langs->trans("MemberType").'';
$label .= ' '.$this->getLibStatut(4);
$label .= '
'.$langs->trans("Label").': '.$this->label;
@@ -676,7 +676,22 @@ class AdherentType extends CommonObject
$label .= '
'.$langs->trans("SubscriptionRequired").': '.yn($this->subscription);
}
- $linkstart = '';
+ $option = '';
+
+ $url = DOL_URL_ROOT.'/adherents/type.php?rowid='.((int) $this->id);
+
+ if ($option != 'nolink') {
+ // Add param to save lastsearch_values or not
+ $add_save_lastsearch_values = ($save_lastsearch_value == 1 ? 1 : 0);
+ if ($save_lastsearch_value == -1 && preg_match('/list\.php/', $_SERVER["PHP_SELF"])) {
+ $add_save_lastsearch_values = 1;
+ }
+ if ($add_save_lastsearch_values) {
+ $url .= '&save_lastsearch_values=1';
+ }
+ }
+
+ $linkstart = '';
$linkend = '';
$result .= $linkstart;
@@ -656,19 +656,19 @@ class AdherentType extends CommonObject
* Return clicable name (with picto eventually)
*
- * @param int $withpicto 0=No picto, 1=Include picto into link, 2=Only picto
- * @param int $maxlen length max label
- * @param int $notooltip 1=Disable tooltip
- * @return string String with URL
+ * @param int $withpicto 0=No picto, 1=Include picto into link, 2=Only picto
+ * @param int $maxlen length max label
+ * @param int $notooltip 1=Disable tooltip
+ * @param string $morecss Add more css on link
+ * @param int $save_lastsearch_value -1=Auto, 0=No save of lastsearch_values when clicking, 1=Save lastsearch_values whenclicking
+ * @return string String with URL
*/